@@ -298,7 +298,7 @@ globus_result_t lcmaps_callout( va_list ap)
 
     /* When we are using the sharing service, we get a PEM file as extra
      * argument */
-    if(strcmp(service, "sharing") == 0)	{
+    if(service && strcmp(service, "sharing") == 0)	{
 	/* Test whether we use a version which actually supports sharing,
 	 * otherwise the va_arg will cause a crash */
 	rc=globus_module_get_version(GLOBUS_GSI_GSS_ASSIST_MODULE,&version);
