@@ -56,6 +56,8 @@
 #include <globus_gsi_credential.h>
 #include <globus_gsi_proxy.h>
 
+/* Defined in globus_gsi_gss_constants.h as
+ * gss_delegation_state_t */
 typedef enum
 {
     GSS_DELEGATION_START,
@@ -64,6 +66,8 @@ typedef enum
     GSS_DELEGATION_SIGN_CERT
 } llgt_gss_delegation_state_t;
 
+/* Defined in globus_gsi_gss_constants.h as
+ * gss_con_st_t */
 typedef enum {
     GSS_CON_ST_HANDSHAKE = 0,
     GSS_CON_ST_FLAGS,
@@ -72,6 +76,8 @@ typedef enum {
     GSS_CON_ST_DONE
 } llgt_gss_con_st_t;
 
+/* Defined in gssapi_openssl.h as
+ * struct gss_ctx_id_desc_struct and gss_ctx_id_desc */
 typedef struct llgt_gss_ctx_id_desc_struct{
     globus_mutex_t                      mutex;
     globus_gsi_callback_data_t          callback_data;
@@ -83,6 +89,19 @@ typedef struct llgt_gss_ctx_id_desc_struct{
     OM_uint32                           req_flags;
     OM_uint32                           ctx_flags;
     int                                 cred_obtained;
+#if OPENSSL_VERSION_NUMBER >= 0x10000100L
+    /** For GCM ciphers, sequence number of next read MAC token */
+    uint64_t                            mac_read_sequence;
+    /** For GCM ciphers, sequence number of next write MAC token */
+    uint64_t                            mac_write_sequence;
+    /** For GCM ciphers, key for MAC token generation/validation */
+    unsigned char *                     mac_key;
+    /**
+     * For GCM ciphers, fixed part of the IV for MAC token
+     * generation/validation
+     */
+    unsigned char *                     mac_iv_fixed;
+#endif
     SSL *                               gss_ssl; 
     BIO *                               gss_rbio;
     BIO *                               gss_wbio;
@@ -93,7 +112,9 @@ typedef struct llgt_gss_ctx_id_desc_struct{
     gss_OID_set                         extension_oids;
 } llgt_gss_ctx_id_desc;
 
-typedef struct lcmaps_gss_cred_id_desc_struct {
+/* Defined in gssapi_openssl.h as
+ * struct gss_cred_id_desc_struct and gss_cred_id_desc */
+typedef struct llgt_gss_cred_id_desc_struct {
     globus_gsi_cred_handle_t            cred_handle;
     gss_name_t                          globusid;
     gss_cred_usage_t                    cred_usage;
