@@ -74,13 +74,25 @@
 #endif
 
 /* Prototypes */
-char* llgt_get_client_name(gss_ctx_id_t context);
+globus_result_t llgt_get_client_name(gss_ctx_id_t context, char **client_name);
 gss_cred_id_t llgt_get_user_cred_handle(gss_ctx_id_t context_handle);
 
+/* Convert a pemstring into a (new) gss_cred_id_t and the DN of the EEC */
+globus_result_t llgt_pem_to_gsscred(char *pem_buf,
+				    gss_cred_id_t *gss_cred,
+				    char **clientname);
+
+void llgt_cleanup_gss_cred_id_t(gss_cred_id_t user_cred_handle);
+
 void llgt_open_log(void);
 void llgt_close_log(void);
 
+#ifdef __GNUC__
+void llgt_logmsg (int priority, const char* format, ...)
+    __attribute__((format(printf,2,3)));
+#else
 void llgt_logmsg (int priority, const char* format, ...);
+#endif
 
 void llgt_enable_debugging_mode(void);
 int llgt_is_debugmode_enabled(void);
